"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const commander_1 = require("commander");
const fs_extra_1 = __importDefault(require("fs-extra"));
const path_1 = __importDefault(require("path"));
const TEMPLATE_DIR = path_1.default.resolve(__dirname, '../template');
const TEMPLATE_DIST_PATH = path_1.default.resolve(TEMPLATE_DIR, 'dist');
async function main() {
    const callerPath = process.cwd();
    const program = new commander_1.Command();
    program.option('--out <path>', 'set the output dir', callerPath);
    program.requiredOption('--plan <path>', 'set the relative path to Terraform plan');
    program.parse(process.argv);
    const inputOpts = program.opts();
    const outDirPath = path_1.default.resolve(callerPath, inputOpts.out, 'terraform-visual-report');
    const planFilePath = path_1.default.resolve(callerPath, inputOpts.plan);
    console.log(`outDirPath:   ${outDirPath}`);
    console.log(`planFilePath: ${planFilePath}`);
    await fs_extra_1.default.copy(TEMPLATE_DIST_PATH, outDirPath);
    const tfBuffer = await fs_extra_1.default.readFile(planFilePath);
    const tfContent = tfBuffer.toString();
    await fs_extra_1.default.writeFile(path_1.default.resolve(outDirPath, 'plan.js'), `window.TF_PLAN = ${tfContent}`);
    const indexFilePath = path_1.default.resolve(outDirPath, 'index.html');
    console.log('');
    console.log('\x1b[32m%s\x1b[0m', 'Report generated successfully!');
    console.log('\x1b[32m%s\x1b[0m', `Please run "open ${path_1.default.relative(callerPath, indexFilePath)}"`);
}
try {
    main();
}
catch (err) {
    console.log('Unhandled error', err);
}
